@@ -2,6 +2,10 @@ from django.db import models
 from django_countries.fields import CountryField
 
 
+def en_zed():
+    return 'NZ'
+
+
 class Person(models.Model):
     name = models.CharField(max_length=50)
     country = CountryField()
@@ -11,3 +15,8 @@ class Person(models.Model):
 
 class AllowNull(models.Model):
     country = CountryField(null=True)
+
+
+class Legacy(models.Model):
+    default = CountryField(default='AU', null=True)
+    default_callable = CountryField(default=en_zed)
